    $ strava-offline --help | grep report-
      report-bikes         Show all-time report by bike
      report-yearly        Show yearly report by activity type
      report-yearly-bikes  Show yearly report by bike
